@@ -1,7 +1,9 @@
-import utils.utils as utils
+import defichainUtils.utils.utils as utils
 
 def decodeCustomTx(hex):
-    # Hex String without OP_RETURN and DfTx Marker
+    '''
+    Hex String without OP_RETURN and DfTx Marker
+    ''' 
     functionMarker = utils.hexToString(hex[:2])
     if functionMarker == 'j':
         res = decodeSetGovVariableHeight(hex[2:])
