@@ -1,7 +1,7 @@
 import json
 import requests
-import utils.bech32 as bech32
-import utils.base58 as base58
+import defichainUtils.utils.bech32 as bech32
+import defichainUtils.utils.base58 as base58
 
 def int2bytes(i:int, enc, length=None):
     if length == None:
